summaryrefslogtreecommitdiffstats
path: root/perl-install/fs/mount_point.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/fs/mount_point.pm')
-rw-r--r--perl-install/fs/mount_point.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/perl-install/fs/mount_point.pm b/perl-install/fs/mount_point.pm
index dc1da482c..e1a09d934 100644
--- a/perl-install/fs/mount_point.pm
+++ b/perl-install/fs/mount_point.pm
@@ -80,8 +80,8 @@ sub validate_mount_points {
$m{$m} and die N("Duplicate mount point %s", $m);
$m{$m} = 1;
- #- in case the type does not correspond, force it to ext3
- fs::type::set_fs_type($_, 'ext3') if !isTrueFS($_) && !isOtherAvailableFS($_);
+ #- in case the type does not correspond, force it to default fs (ext4 currently)
+ fs::type::set_fs_type($_, defaultFS()) if !isTrueFS($_) && !isOtherAvailableFS($_);
}
1;
}